This data is constructed based on the Sequenced Treatment Alternatives to Relieve Depression (STAR*D) study. Due to a data confidentiality agreement, we are not able to provide the original dataset. Here, we generate simulated data that are similar to the original dataset.
data("SSTARD.onestage")A list with 319 observations.
YPatients' responses. The larger the better.
ATreatments patients receive.
XA 319*305 matrix consisting of patients' baseline covariates.
Fava, M., Rush, A. J., Trivedi, M. H., Nierenberg, A. A., Thase, M. E., Sack- eim, H. A., Quitkin, F. M., Wisniewski, S., Lavori, P. W., Rosenbaum, J. F. et al. (2003). Background and rationale for the Sequenced Treatment Alternatives to Relieve Depression (STAR* D) study. Psychiatric Clinics of North America, 26: 457-494.
Rush, A. J., Fava, M., Wisniewski, S. R., Lavori, P. W., Trivedi, M. H., Sack- eim, H. A., Thase, M. E., Nierenberg, A. A., Quitkin, F. M., Kashner, T. M. et al. (2004). Sequenced treatment alternatives to relieve depression (STAR* D): rationale and design. Controlled clinical trials, 25: 119-142.
# NOT RUN {
data(SSTARD.onestage)
# }
Run the code above in your browser using DataLab